@@ -10,7 +10,7 @@ struct LxmlElementBase;
 struct LxmlElementClassLookup;
 struct LxmlFallbackElementClassLookup;
 
-/* "src/lxml/lxml.etree.pyx":290
+/* "src/lxml/lxml.etree.pyx":302
  * cdef class _BaseParser
  * cdef class QName
  * ctypedef public xmlNode* (*_node_to_node_function)(xmlNode*)             # <<<<<<<<<<<<<<
@@ -19,7 +19,7 @@ struct LxmlFallbackElementClassLookup;
  */
 typedef xmlNode *(*_node_to_node_function)(xmlNode *);
 
-/* "src/lxml/lxml.etree.pyx":286
+/* "src/lxml/lxml.etree.pyx":298
  * 
  * # forward declarations
  * cdef public class _Document [ type LxmlDocumentType, object LxmlDocument ]             # <<<<<<<<<<<<<<
@@ -35,7 +35,7 @@ struct LxmlDocument {
   struct __pyx_obj_4lxml_5etree__BaseParser *_parser;
 };
 
-/* "src/lxml/lxml.etree.pyx":287
+/* "src/lxml/lxml.etree.pyx":299
  * # forward declarations
  * cdef public class _Document [ type LxmlDocumentType, object LxmlDocument ]
  * cdef public class _Element [ type LxmlElementType, object LxmlElement ]             # <<<<<<<<<<<<<<
@@ -50,7 +50,7 @@ struct LxmlElement {
   PyObject *_tag;
 };
 
-/* "src/lxml/lxml.etree.pyx":1697
+/* "src/lxml/lxml.etree.pyx":1734
  * 
  * 
  * cdef public class _ElementTree [ type LxmlElementTreeType,             # <<<<<<<<<<<<<<
@@ -64,12 +64,12 @@ struct LxmlElementTree {
   struct LxmlElement *_context_node;
 };
 
-/* "src/lxml/lxml.etree.pyx":2314
+/* "src/lxml/lxml.etree.pyx":2372
  * 
  * 
  * cdef public class _ElementTagMatcher [ object LxmlElementTagMatcher,             # <<<<<<<<<<<<<<
  *                                        type LxmlElementTagMatcherType ]:
- *     cdef object _pystrings
+ *     """
  */
 struct LxmlElementTagMatcher {
   PyObject_HEAD
@@ -80,12 +80,12 @@ struct LxmlElementTagMatcher {
   char *_name;
 };
 
-/* "src/lxml/lxml.etree.pyx":2342
+/* "src/lxml/lxml.etree.pyx":2403
  *                 self._name = NULL
  * 
  * cdef public class _ElementIterator(_ElementTagMatcher) [             # <<<<<<<<<<<<<<
  *     object LxmlElementIterator, type LxmlElementIteratorType ]:
- *     # we keep Python references here to control GC
+ *     """
  */
 struct LxmlElementIterator {
   struct LxmlElementTagMatcher __pyx_base;
@@ -93,7 +93,7 @@ struct LxmlElementIterator {
   _node_to_node_function _next_element;
 };
 
-/* "/home/sbehnel/source/Python/lxml/lxml-release/src/lxml/classlookup.pxi":6
+/* "/home/stefan/source/Python/lxml/lxml-release/src/lxml/classlookup.pxi":6
  * # Custom Element classes
  * 
  * cdef public class ElementBase(_Element) [ type LxmlElementBaseType,             # <<<<<<<<<<<<<<
@@ -104,7 +104,7 @@ struct LxmlElementBase {
   struct LxmlElement __pyx_base;
 };
 
-/* "/home/sbehnel/source/Python/lxml/lxml-release/src/lxml/classlookup.pxi":184
+/* "/home/stefan/source/Python/lxml/lxml-release/src/lxml/classlookup.pxi":179
  * # Element class lookup
  * 
  * ctypedef public object (*_element_class_lookup_function)(object, _Document, xmlNode*)             # <<<<<<<<<<<<<<
@@ -113,7 +113,7 @@ struct LxmlElementBase {
  */
 typedef PyObject *(*_element_class_lookup_function)(PyObject *, struct LxmlDocument *, xmlNode *);
 
-/* "/home/sbehnel/source/Python/lxml/lxml-release/src/lxml/classlookup.pxi":187
+/* "/home/stefan/source/Python/lxml/lxml-release/src/lxml/classlookup.pxi":182
  * 
  * # class to store element class lookup functions
  * cdef public class ElementClassLookup [ type LxmlElementClassLookupType,             # <<<<<<<<<<<<<<
@@ -125,7 +125,7 @@ struct LxmlElementClassLookup {
   _element_class_lookup_function _lookup_function;
 };
 
-/* "/home/sbehnel/source/Python/lxml/lxml-release/src/lxml/classlookup.pxi":196
+/* "/home/stefan/source/Python/lxml/lxml-release/src/lxml/classlookup.pxi":191
  *         self._lookup_function = NULL # use default lookup
  * 
  * cdef public class FallbackElementClassLookup(ElementClassLookup) \             # <<<<<<<<<<<<<<
@@ -168,7 +168,7 @@ __PYX_EXTERN_C DL_IMPORT(void) setElementClassLookupFunction(_element_class_look
 __PYX_EXTERN_C DL_IMPORT(PyObject) *lookupDefaultElementClass(PyObject *, PyObject *, xmlNode *);
 __PYX_EXTERN_C DL_IMPORT(PyObject) *lookupNamespaceElementClass(PyObject *, PyObject *, xmlNode *);
 __PYX_EXTERN_C DL_IMPORT(PyObject) *callLookupFallback(struct LxmlFallbackElementClassLookup *, struct LxmlDocument *, xmlNode *);
-__PYX_EXTERN_C DL_IMPORT(int) tagMatches(xmlNode *, char *, char *);
+__PYX_EXTERN_C DL_IMPORT(int) tagMatches(xmlNode *, const xmlChar *, const xmlChar *);
 __PYX_EXTERN_C DL_IMPORT(struct LxmlDocument) *documentOrRaise(PyObject *);
 __PYX_EXTERN_C DL_IMPORT(struct LxmlElement) *rootNodeOrRaise(PyObject *);
 __PYX_EXTERN_C DL_IMPORT(int) hasText(xmlNode *);
@@ -178,13 +178,13 @@ __PYX_EXTERN_C DL_IMPORT(PyObject) *tailOf(xmlNode *);
 __PYX_EXTERN_C DL_IMPORT(int) setNodeText(xmlNode *, PyObject *);
 __PYX_EXTERN_C DL_IMPORT(int) setTailText(xmlNode *, PyObject *);
 __PYX_EXTERN_C DL_IMPORT(PyObject) *attributeValue(xmlNode *, xmlAttr *);
-__PYX_EXTERN_C DL_IMPORT(PyObject) *attributeValueFromNsName(xmlNode *, char *, char *);
+__PYX_EXTERN_C DL_IMPORT(PyObject) *attributeValueFromNsName(xmlNode *, const xmlChar *, const xmlChar *);
 __PYX_EXTERN_C DL_IMPORT(PyObject) *getAttributeValue(struct LxmlElement *, PyObject *, PyObject *);
 __PYX_EXTERN_C DL_IMPORT(PyObject) *iterattributes(struct LxmlElement *, int);
 __PYX_EXTERN_C DL_IMPORT(PyObject) *collectAttributes(xmlNode *, int);
 __PYX_EXTERN_C DL_IMPORT(int) setAttributeValue(struct LxmlElement *, PyObject *, PyObject *);
 __PYX_EXTERN_C DL_IMPORT(int) delAttribute(struct LxmlElement *, PyObject *);
-__PYX_EXTERN_C DL_IMPORT(int) delAttributeFromNsName(xmlNode *, char *, char *);
+__PYX_EXTERN_C DL_IMPORT(int) delAttributeFromNsName(xmlNode *, const xmlChar *, const xmlChar *);
 __PYX_EXTERN_C DL_IMPORT(int) hasChild(xmlNode *);
 __PYX_EXTERN_C DL_IMPORT(xmlNode) *findChild(xmlNode *, Py_ssize_t);
 __PYX_EXTERN_C DL_IMPORT(xmlNode) *findChildForwards(xmlNode *, Py_ssize_t);
@@ -192,15 +192,15 @@ __PYX_EXTERN_C DL_IMPORT(xmlNode) *findChildBackwards(xmlNode *, Py_ssize_t);
 __PYX_EXTERN_C DL_IMPORT(xmlNode) *nextElement(xmlNode *);
 __PYX_EXTERN_C DL_IMPORT(xmlNode) *previousElement(xmlNode *);
 __PYX_EXTERN_C DL_IMPORT(void) appendChild(struct LxmlElement *, struct LxmlElement *);
-__PYX_EXTERN_C DL_IMPORT(PyObject) *pyunicode(char *);
+__PYX_EXTERN_C DL_IMPORT(PyObject) *pyunicode(const xmlChar *);
 __PYX_EXTERN_C DL_IMPORT(PyObject) *utf8(PyObject *);
 __PYX_EXTERN_C DL_IMPORT(PyObject) *getNsTag(PyObject *);
 __PYX_EXTERN_C DL_IMPORT(PyObject) *getNsTagWithEmptyNs(PyObject *);
 __PYX_EXTERN_C DL_IMPORT(PyObject) *namespacedName(xmlNode *);
-__PYX_EXTERN_C DL_IMPORT(PyObject) *namespacedNameFromNsName(char *, char *);
+__PYX_EXTERN_C DL_IMPORT(PyObject) *namespacedNameFromNsName(const xmlChar *, const xmlChar *);
 __PYX_EXTERN_C DL_IMPORT(void) iteratorStoreNext(struct LxmlElementIterator *, struct LxmlElement *);
 __PYX_EXTERN_C DL_IMPORT(void) initTagMatch(struct LxmlElementTagMatcher *, PyObject *);
-__PYX_EXTERN_C DL_IMPORT(xmlNs) *findOrBuildNodeNsPrefix(struct LxmlDocument *, xmlNode *, char *, char *);
+__PYX_EXTERN_C DL_IMPORT(xmlNs) *findOrBuildNodeNsPrefix(struct LxmlDocument *, xmlNode *, const xmlChar *, const xmlChar *);
 
 #endif /* !__PYX_HAVE_API__lxml__etree */
 
