@@ -1,4 +1,4 @@
-﻿# -*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 import unittest, doctest
 
 # These tests check that error handling in the Pyrex code is
@@ -6,10 +6,16 @@ import unittest, doctest
 # It is likely that if there are errors, instead of failing the code
 # will simply crash.
 
-import sys, gc
+import sys, gc, os.path
 from lxml import etree
 
-class ErrorTestCase(unittest.TestCase):
+this_dir = os.path.dirname(__file__)
+if this_dir not in sys.path:
+    sys.path.insert(0, this_dir) # needed for Py3
+
+from common_imports import HelperTestCase
+
+class ErrorTestCase(HelperTestCase):
     etree = etree
 
     def test_bad_element(self):
@@ -41,4 +47,4 @@ def test_suite():
     return suite
 
 if __name__ == '__main__':
-    print 'to test use test.py %s' % __file__
+    print('to test use test.py %s' % __file__)
